moviepy#

Imports everything that you need from the MoviePy submodules so that every thing can be directly imported with from moviepy import *.

Modules

moviepy.Clip

Implements the central object of MoviePy, the Clip, and all the methods that are common to the two subclasses of Clip, VideoClip and AudioClip.

moviepy.Effect()

Base abstract class for all effects in MoviePy.

moviepy.audio

Everything about audio manipulation.

moviepy.config

Third party programs configuration for MoviePy.

moviepy.decorators

Decorators used by moviepy.

moviepy.tools

Misc.

moviepy.video

Everything about video manipulation.