moviepy.audio.AudioClip.CompositeAudioClip#

class moviepy.audio.AudioClip.CompositeAudioClip(clips)[source]#

Clip made by composing several AudioClips.

An audio clip made by putting together several audio clips.

Parameters:

clips – List of audio clips, which may start playing at different times or together, depends on their start attributes. If all have their duration attribute set, the duration of the composite clip is computed automatically.

property ends#

Returns ending times for all clips in the composition.

frame_function(t)[source]#

Renders a frame for the composition for the time t.

property starts#

Returns starting times for all clips in the composition.