moviepy.video.fx.MultiplySpeed#
- class moviepy.video.fx.MultiplySpeed.MultiplySpeed(factor: float = None, final_duration: float = None)[source]#
Returns a clip playing the current clip but at a speed multiplied by
factor.Instead of factor one can indicate the desired
final_durationof the clip, and the factor will be automatically computed. The same effect is applied to the clip’s audio and mask if any.- copy()#
Return a shallow copy of an Effect.
You must always copy an
Effectbefore applying, because some of them will modify their own attributes when applied. For example, setting a previously unset property by using target clip property.If we was to use the original effect, calling the same effect multiple times could lead to different properties, and different results for equivalent clips.
By using copy, we ensure we can use the same effect object multiple times while maintaining the same behavior/result.
In a way, copy makes the effect himself being kind of idempotent.