moviepy#
Imports everything that you need from the MoviePy submodules so that every thing
can be directly imported with from moviepy import *.
Modules
Implements the central object of MoviePy, the Clip, and all the methods that are common to the two subclasses of Clip, VideoClip and AudioClip. |
|
Base abstract class for all effects in MoviePy. |
|
Everything about audio manipulation. |
|
Third party programs configuration for MoviePy. |
|
Decorators used by moviepy. |
|
Misc. |
|
Everything about video manipulation. |