moviepy.audio.AudioClip.CompositeAudioClip#
- class moviepy.audio.AudioClip.CompositeAudioClip(clips)[source]#
Clip made by composing several AudioClips.
An audio clip made by putting together several audio clips.
- Parameters:
clips – List of audio clips, which may start playing at different times or together, depends on their
startattributes. If all have theirdurationattribute set, the duration of the composite clip is computed automatically.
- property ends#
Returns ending times for all clips in the composition.
- property starts#
Returns starting times for all clips in the composition.